@@ -3,7 +3,7 @@ from __future__ import annotations
 import attrs
 import typing
 import enum
-from aapi import *
+from aapi.bases import AAPIObject
 
 
 @attrs.define
